OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Сториџот не е валиден",
    "Unknown error" : "Непозната грешка",
    "All files" : "Сите датотеки",
    "Saved" : "Снимено",
    "Home" : "Дома",
    "Close" : "Затвори",
    "Favorites" : "Омилени",
    "Upload cancelled." : "Преземањето е прекинато.",
    "Uploading..." : "Подигнувам...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Подигање на датотека е во тек. Напуштење на страницата ќе го прекине.",
    "Actions" : "Акции",
    "Download" : "Преземи",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Unshare" : "Не споделувај",
    "Files" : "Датотеки",
    "Details" : "Детали:",
    "Select" : "Избери",
    "Pending" : "Чека",
    "Invalid path" : "Грешна патека",
    "This operation is forbidden" : "Операцијата не е дозволена",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Променето",
    "{dirs} and {files}" : "{dirs} и {files}",
    "New" : "Ново",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "Your storage is full, files can not be updated or synced anymore!" : "Вашиот сториџ е полн, датотеките веќе не можат да се освежуваат или синхронизираат!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Вашиот сториџ е скоро полн ({usedSpacePercent}%)",
    "Path" : "Патека",
    "Favorited" : "Омилени",
    "Favorite" : "Омилен",
    "Folder" : "Папка",
    "New folder" : "Нова папка",
    "{newname} already exists" : "{newname} веќе постои",
    "Upload" : "Подигни",
    "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
    "You created %1$s" : "Вие креиравте %1$s",
    "%2$s created %1$s" : "%2$s креирано %1$s",
    "You changed %1$s" : "Вие изменивте %1$s",
    "%2$s changed %1$s" : "%2$s променето %1$s",
    "You deleted %1$s" : "Вие избришавте %1$s",
    "%2$s deleted %1$s" : "%2$s избришани %1$s",
    "Changed by %2$s" : "Променето од %2$s",
    "Deleted by %2$s" : "Избришано од %2$s",
    "Restored by %2$s" : "Повратено од %2$s",
    "Upload (max. %s)" : "Префрлање (макс. %s)",
    "File handling" : "Ракување со датотеки",
    "Maximum upload size" : "Максимална големина за подигање",
    "max. possible: " : "макс. можно:",
    "Save" : "Сними",
    "Missing permissions to edit from here." : "Недостасуваат пермисии за да уредувате од тука",
    "Settings" : "Подесувања",
    "WebDAV" : "WebDAV",
    "No files in here" : "Тука нема датотеки",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Select all" : "Избери се",
    "Upload too large" : "Фајлот кој се вчитува е преголем",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
    "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
    "Text file" : "Текстуална датотека",
    "New text file.txt" : "Нова текстуална датотека file.txt"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
